==> nextcloud-26.0.11p1.tgz: nextcloud/apps/serverinfo/l10n/gl.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "A información da CPU non está dispoñíbel",
    "Load average: {cpu} (last minute)" : "Carga media: {cpu} (último minuto)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Total: {memTotalBytes}/Uso actual: {memUsageBytes}",
    "RAM info not available" : "A información de RAM non está dispoñíbel",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Total: {swapTotalBytes}/Uso actual: {swapUsageBytes}",
    "SWAP info not available" : "A información de SWAP non está dispoñíbel",
    "Copied!" : "Copiado!",
    "Not supported!" : "Non admitido!",
    "Press ⌘-C to copy." : "Prema ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Prema Ctrl-C para copiar.",
    "System" : "Sistema",
    "Monitoring" : "Seguimento",
    "Monitoring app with useful server information" : "Aplicación de seguimento con información útil do servidor",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Fornece información útil do servidor, como a carga da CPU, o uso da memoria RAM, o uso do disco, o número de usuarios, etc.",
    "Operating System:" : "Sistema operativo",
    "CPU:" : "CPU:",
    "Unknown Processor" : "Procesador descoñecido",
    "Memory:" : "Memoria:",
    "Server time:" : "Hora do servidor:",
    "Uptime:" : "Tempo de actividade:",
    "Temperature" : "Temperatura",
    "Load" : "Carga",
    "Memory" : "Memoria",
    "Disk" : "Disco",
    "Mount:" : "Montaxe:",
    "Filesystem:" : "Sistema de ficheiros:",
    "Size:" : "Tamaño:",
    "Available:" : "Dispoñíbel",
    "Used:" : "Usado:",
    "Files:" : "Ficheiros:",
    "Storages:" : "Almacenamentos:",
    "Free Space:" : "Espazo libre:",
    "Network" : "Rede",
    "Hostname:" : "Nome de máquina:",
    "DNS:" : "DNS:",
    "Gateway:" : "Pasarela:",
    "Status:" : "Estado:",
    "Speed:" : "Velocidade:",
    "Duplex:" : "Dúplex:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Usuarios activos",
    "Total users:" : "Total de usuarios:",
    "24 hours:" : "24 horas:",
    "1 hour:" : "1 hora:",
    "5 mins:" : "5 min:",
    "Shares" : "Comparticións",
    "Users:" : "Usuarios:",
    "Groups:" : "Grupos:",
    "Links:" : "Ligazóns:",
    "Emails:" : "Correos-e",
    "Federated sent:" : "Envíos á federación:",
    "Federated received:" : "Recibido da federación:",
    "Talk conversations:" : "Conversas co Talk:",
    "PHP" : "PHP",
    "Version:" : "Versión:",
    "Memory limit:" : "Límite de memoria:",
    "Max execution time:" : "Tempo máximo de execución:",
    "Upload max size:" : "Tamaño máximo de envío:",
    "OPcache Revalidate Frequency:" : "Frecuencia de revalidación de OPcache:",
    "Extensions:" : "Extensións:",
    "Unable to list extensions" : "Non é posíbel listar as extensións",
    "Show phpinfo" : "Amosar phpinfo",
    "Database" : "Base de datos",
    "Type:" : "Tipo:",
    "External monitoring tool" : "Ferramenta externa de supervisión",
    "Use this end point to connect an external monitoring tool:" : "Use este punto final para conectar unha ferramenta de supervisión externa:",
    "Copy" : "Copiar",
    "Output in JSON" : "Saída en JSON",
    "Skip app updates (including app updates will send an external request to the app store)" : "Omitir actualizacións de aplicacións (se se inclúen as actualizacións de aplicacións enviarase unha solicitude externa á tenda de aplicacións)",
    "Skip server update" : "Omitir actualización do servidor",
    "To use an access token, please generate one then set it using the following command:" : "Para usar un testemuño de acceso, xere un e configúreo usando a seguinte orde:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "A continuación, pase o testemuño coa cabeceira «NC-Token» ao consultar o URL anterior."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-27.1.3.tgz: nextcloud/apps/serverinfo/l10n/gl.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "A información da CPU non está dispoñíbel",
    "Load average: {cpu} (last minute)" : "Carga media: {cpu} (último minuto)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Total: {memTotalBytes}/Uso actual: {memUsageBytes}",
    "RAM info not available" : "A información de RAM non está dispoñíbel",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Total: {swapTotalBytes}/Uso actual: {swapUsageBytes}",
    "SWAP info not available" : "A información de SWAP non está dispoñíbel",
    "Not supported!" : "Non admitido!",
    "Press ⌘-C to copy." : "Prema ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Prema Ctrl-C para copiar.",
    "System" : "Sistema",
    "Monitoring" : "Seguimento",
    "Monitoring app with useful server information" : "Aplicación de seguimento con información útil do servidor",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Fornece información útil do servidor, como a carga da CPU, o uso da memoria RAM, o uso do disco, o número de usuarios, etc.",
    "Operating System:" : "Sistema operativo",
    "CPU:" : "CPU:",
    "Unknown Processor" : "Procesador descoñecido",
    "Memory:" : "Memoria:",
    "Server time:" : "Hora do servidor:",
    "Uptime:" : "Tempo de actividade:",
    "Temperature" : "Temperatura",
    "Load" : "Carga",
    "Memory" : "Memoria",
    "Disk" : "Disco",
    "Mount:" : "Montaxe:",
    "Filesystem:" : "Sistema de ficheiros:",
    "Size:" : "Tamaño:",
    "Available:" : "Dispoñíbel",
    "Used:" : "Usado:",
    "Files:" : "Ficheiros:",
    "Storages:" : "Almacenamentos:",
    "Free Space:" : "Espazo libre:",
    "Network" : "Rede",
    "Hostname:" : "Nome de máquina:",
    "DNS:" : "DNS:",
    "Gateway:" : "Pasarela:",
    "Status:" : "Estado:",
    "Speed:" : "Velocidade:",
    "Duplex:" : "Dúplex:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Usuarios activos",
    "Total users:" : "Total de usuarios:",
    "24 hours:" : "24 horas:",
    "1 hour:" : "1 hora:",
    "5 mins:" : "5 min:",
    "Shares" : "Comparticións",
    "Users:" : "Usuarios:",
    "Groups:" : "Grupos:",
    "Links:" : "Ligazóns:",
    "Emails:" : "Correos-e",
    "Federated sent:" : "Envíos á federación:",
    "Federated received:" : "Recibido da federación:",
    "Talk conversations:" : "Conversas co Talk:",
    "PHP" : "PHP",
    "Version:" : "Versión:",
    "Memory limit:" : "Límite de memoria:",
    "Max execution time:" : "Tempo máximo de execución:",
    "Upload max size:" : "Tamaño máximo de envío:",
    "OPcache Revalidate Frequency:" : "Frecuencia de revalidación de OPcache:",
    "Extensions:" : "Extensións:",
    "Unable to list extensions" : "Non é posíbel listar as extensións",
    "Show phpinfo" : "Amosar phpinfo",
    "Database" : "Base de datos",
    "Type:" : "Tipo:",
    "External monitoring tool" : "Ferramenta externa de supervisión",
    "You can connect an external monitoring tool by using this end point:" : "Pode conectar unha ferramenta externa de seguimento usando este punto final:",
    "Copy" : "Copiar",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Engadindo «?format=json» na fin do URL devolve o resultado en JSON.",
    "To use an access token, please generate one then set it using the following command:" : "Para usar un testemuño de acceso, xere un e configúreo usando a seguinte orde:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "A continuación, pase o testemuño coa cabeceira «NC-Token» ao consultar o URL anterior.",
    "You will get a notification once one of your disks is nearly full." : "Recibirá unha notificación cando un dos seus discos estea case completo."
},
"nplurals=2; plural=(n != 1);");
